==> open-cluster-management-operator-model-6.5.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/ClusterManagerListFluent.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ClusterManagerListFluent<A extends ClusterManagerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ClusterManager item);
  public A setToItems(Integer index,ClusterManager item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.operator.v1.ClusterManager... items);
  public A addAllToItems(Collection<ClusterManager> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.operator.v1.ClusterManager... items);
  public A removeAllFromItems(Collection<ClusterManager> items);
  public A removeMatchingFromItems(Predicate<ClusterManagerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterManager> getItems();
  public List<ClusterManager> buildItems();
  public ClusterManager buildItem(Integer index);
  public ClusterManager buildFirstItem();
  public ClusterManager buildLastItem();
  public ClusterManager buildMatchingItem(Predicate<ClusterManagerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterManagerBuilder> predicate);
  public A withItems(List<ClusterManager> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.operator.v1.ClusterManager... items);
  public Boolean hasItems();
  public ClusterManagerListFluent.ItemsNested<A> addNewItem();
  public ClusterManagerListFluent.ItemsNested<A> addNewItemLike(ClusterManager item);
  public ClusterManagerListFluent.ItemsNested<A> setNewItemLike(Integer index,ClusterManager item);
  public ClusterManagerListFluent.ItemsNested<A> editItem(Integer index);
  public ClusterManagerListFluent.ItemsNested<A> editFirstItem();
  public ClusterManagerListFluent.ItemsNested<A> editLastItem();
  public ClusterManagerListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterManagerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ClusterManagerFluent<ClusterManagerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> open-cluster-management-operator-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/ClusterManagerListFluent.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ClusterManagerListFluent<A extends ClusterManagerListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ClusterManager item);
  public A setToItems(int index,ClusterManager item);
  public A addToItems(io.fabric8.openclustermanagement.api.model.operator.v1.ClusterManager... items);
  public A addAllToItems(Collection<ClusterManager> items);
  public A removeFromItems(io.fabric8.openclustermanagement.api.model.operator.v1.ClusterManager... items);
  public A removeAllFromItems(Collection<ClusterManager> items);
  public A removeMatchingFromItems(Predicate<ClusterManagerBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterManager> getItems();
  public List<ClusterManager> buildItems();
  public ClusterManager buildItem(int index);
  public ClusterManager buildFirstItem();
  public ClusterManager buildLastItem();
  public ClusterManager buildMatchingItem(Predicate<ClusterManagerBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterManagerBuilder> predicate);
  public A withItems(List<ClusterManager> items);
  public A withItems(io.fabric8.openclustermanagement.api.model.operator.v1.ClusterManager... items);
  public Boolean hasItems();
  public ClusterManagerListFluent.ItemsNested<A> addNewItem();
  public ClusterManagerListFluent.ItemsNested<A> addNewItemLike(ClusterManager item);
  public ClusterManagerListFluent.ItemsNested<A> setNewItemLike(int index,ClusterManager item);
  public ClusterManagerListFluent.ItemsNested<A> editItem(int index);
  public ClusterManagerListFluent.ItemsNested<A> editFirstItem();
  public ClusterManagerListFluent.ItemsNested<A> editLastItem();
  public ClusterManagerListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterManagerBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ClusterManagerFluent<ClusterManagerListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
